summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libcvs/cvsdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/libcvs/cvsdialog.cpp')
-rw-r--r--kbabel/catalogmanager/libcvs/cvsdialog.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kbabel/catalogmanager/libcvs/cvsdialog.cpp b/kbabel/catalogmanager/libcvs/cvsdialog.cpp
index 7532320a..054e8489 100644
--- a/kbabel/catalogmanager/libcvs/cvsdialog.cpp
+++ b/kbabel/catalogmanager/libcvs/cvsdialog.cpp
@@ -120,7 +120,7 @@ CVSDialog::CVSDialog( CVS::Command cmd, TQWidget * parent, KSharedConfig* config
// The last encoding will be added at the top of the list, when the seetings will be read.
encodingList << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).arg( "UTF-8" );
encodingList << i18n( "Descriptive encoding name", "Locale ( %1 )" ).arg( TQTextCodec::codecForLocale()->mimeName() );
- encodingList += KGlobal::charsets()->descriptiveEncodingNames();
+ encodingList += TDEGlobal::charsets()->descriptiveEncodingNames();
m_encodingComboBox->insertStringList( encodingList );
connect( oldMessages, TQT_SIGNAL( activated( int ) ),
@@ -217,10 +217,10 @@ void CVSDialog::slotExecuteCommand( )
// Nothing to do here.
if ( _commandLine.isEmpty( ) ) return;
- kdDebug() << "Preparing KProcess" << endl;
+ kdDebug() << "Preparing TDEProcess" << endl;
// Create a new shell process
- p = new KProcess;
+ p = new TDEProcess;
p->setUseShell( true, "/bin/sh" );
if ( _cmd == CVS::Commit ) {
@@ -239,7 +239,7 @@ void CVSDialog::slotExecuteCommand( )
return;
}
- m_encoding = KGlobal::charsets()->encodingForName( m_encodingComboBox->currentText() );
+ m_encoding = TDEGlobal::charsets()->encodingForName( m_encodingComboBox->currentText() );
TQTextCodec* codec = TQTextCodec::codecForName( m_encoding.utf8() );
if ( !codec )
@@ -282,7 +282,7 @@ void CVSDialog::slotExecuteCommand( )
}
// Change the command line to have the real name of the temporary file
- _commandLine.replace( "@LOG@FILE@", KProcess::quote( m_tempFile->name() ) );
+ _commandLine.replace( "@LOG@FILE@", TDEProcess::quote( m_tempFile->name() ) );
// Update the list of log messages
if ( !msg.isEmpty() ) {
@@ -298,19 +298,19 @@ void CVSDialog::slotExecuteCommand( )
}
}
// Set the KProcess' command line.
*p << _commandLine;
- connect( p, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ),
- this, TQT_SLOT ( slotProcessStdout( KProcess*, char*, int ) ) );
- connect( p, TQT_SIGNAL( receivedStderr( KProcess*, char*, int ) ),
- this, TQT_SLOT ( slotProcessStderr( KProcess*, char*, int ) ) );
- connect( p, TQT_SIGNAL( processExited( KProcess* ) ),
- this, TQT_SLOT( slotProcessExited( KProcess* ) ) );
+ connect( p, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ),
+ this, TQT_SLOT ( slotProcessStdout( TDEProcess*, char*, int ) ) );
+ connect( p, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ),
+ this, TQT_SLOT ( slotProcessStderr( TDEProcess*, char*, int ) ) );
+ connect( p, TQT_SIGNAL( processExited( TDEProcess* ) ),
+ this, TQT_SLOT( slotProcessExited( TDEProcess* ) ) );
output->append( i18n( "[ Starting command ]" ) );
- if ( p->start( KProcess::NotifyOnExit, KProcess::Communication( KProcess::AllOutput ) ) ) {
+ if ( p->start( TDEProcess::NotifyOnExit, TDEProcess::Communication( TDEProcess::AllOutput ) ) ) {
// Disable the main button (and the log edit if in commit mode) to
// indicate activity.
mainBtn->setEnabled( false );
@@ -323,7 +323,7 @@ void CVSDialog::slotExecuteCommand( )
}
}
-void CVSDialog::slotProcessStdout( KProcess*, char * buffer, int len )
+void CVSDialog::slotProcessStdout( TDEProcess*, char * buffer, int len )
{
output->append( TQString::fromLocal8Bit( buffer, len ) );
// Set the cursor's position at the end of the output.
@@ -334,7 +334,7 @@ void CVSDialog::slotProcessStdout( KProcess*, char * buffer, int len )
_statusOutput += TQString::fromLocal8Bit( buffer, len );
}
-void CVSDialog::slotProcessStderr( KProcess*, char * buffer, int len )
+void CVSDialog::slotProcessStderr( TDEProcess*, char * buffer, int len )
{
// If an error occurs while executing the command display stderr in
// another color.
@@ -345,7 +345,7 @@ void CVSDialog::slotProcessStderr( KProcess*, char * buffer, int len )
output->setCursorPosition( output->lines( ), 0 );
}
-void CVSDialog::slotProcessExited( KProcess * p )
+void CVSDialog::slotProcessExited( TDEProcess * p )
{
if ( p->exitStatus( ) )
output->append( i18n( "[ Exited with status %1 ]" ).arg( p->exitStatus( ) ) );
@@ -298,19 +298,19 @@ void CVSDialog::slotExecuteCommand( )
}
}
- // Set the KProcess' command line.
+ // Set the TDEProcess' command line.
*p << _commandLine;